Authors: Caleb Fangmeier
Date: May 30, 2018
## Object Kinematics and Multiplicities

The definition of efficiency and purity being used for the electron seeding studies depends on sim-tracks for determining whether a reconstructed GSF track corresponds with a "real" electron or not. Sim-tracks considered for truth-matching must fulfill the following requirements.

  - is either an electron or positron
  - originates in the luminous region
  - is in the geometric acceptance of the ECAL ($|\eta|<3.0$)

Following are a few plots showing basic kinematic distributions as well as the multiplicity per event. All distributions normalized to 1.


<div class="row">

<div class="col-md-6 row_fig">
fig::good_sim_kinem|Kinematic distributions for sim electrons. Interestingly, both tt and zee exhibit large peaks at low $p_T$. This could be explained in the case of Zee as electrons from pileup interactions, and for tt as both from pileup and from soft electrons from B decays.
</div>
<div class="col-md-6 row_fig">
fig::number_of_sim_els|Multiplicity distributions for sim electrons. It is good to see that on average, the sim-track selection produces about two electrons. However, it is worth noting that about 20% of the time, one of the electrons is lost. This is most likely due to being outside the ECAL acceptance (ie $\eta>3.0$).
</div>

<div class="col-md-6 row_fig">
fig::seed_kinem|Kinematic distributions for ECAL-Driven Seeds with HOE<0.15
</div>
<div class="col-md-6 row_fig">
fig::number_of_good_seeds|Multiplicity distributions for ECAL-Driven Seeds with HOE<0.15
</div>

<div class="col-md-6 row_fig">
fig::gsf_track_kinem|Kinematic distributions for GSF-Tracks
</div>
<div class="col-md-6 row_fig">
fig::number_of_gsf_tracks|Multiplicity distributions for GSF-Tracks
</div>

<div class="col-md-6 row_fig">
fig::scl_kinem|Kinematic distributions for Super-Clusters with HOE<0.15
</div>
<div class="col-md-6 row_fig">
fig::number_of_good_scls|Multiplicity distributions for Super-Clusters with HOE<0.15
</div>

</div>

## Matching Metrics
In addition to basic metrics like purity and efficiency which are simply the proportion of reco-tracks that match with sim-tracks and the proportion of sim-tracks and match with reco-tracks, it is good to check the frequency of things such as how often a sim-track is matched to multiple reco-tracks, or the frequency of a reco-track being matched to multiple sim-tracks. The various cases and how they are named are demonstrated in the figure below where the grey arrows indicate that the two tracks are matched.

locfig::../docs/common/matching_types.png|Example demonstrating some of the different modalities that can happen curing the matching between sim-tracks and reco-tracks.

In addition, the way the matching itself is done can affect the mapping between sim-tracks and reco-tracks. For example, a $\Delta R<0.2$ matching tends to be more permissive than the (default) matching which requires that the sim-track contain at least 75% of the hits from the reco-track.

And here are the distributions of the frequency of each of these occurences per event.

<div class="row">

<div class="col-md-6 row_fig">
fig::number_of_merged|Merged per event
</div>
<div class="col-md-6 row_fig">
fig::number_of_merged_dR|Merged per event - dR Matched
</div>
<div class="col-md-6 row_fig">
fig::number_of_lost|Lost per event. Interestingly, we seem to be averaging ~1 lost electron per event for both zee and tt, even though these electrons are within the detector acceptance. Most likely, these are going to be overwhelmingly low pt electrons that either don't make it all the way to the ECAL or don't deposit sufficient energy to make a signal above threshold. One could make this distribution vs sim energy to answer this definitively.
</div>
<div class="col-md-6 row_fig">
fig::number_of_lost_dR|Lost per event - dR Matched
</div>
<div class="col-md-6 row_fig">
fig::number_of_split|Split per event
</div>
<div class="col-md-6 row_fig">
fig::number_of_split_dR|Split per event - dR Matched
</div>
<div class="col-md-6 row_fig">
fig::number_of_faked|Fake per event. Note that the definition of \"Fake\" here is different than that in the next section. This is simply a reco-track that fails to match with any sim-track.
</div>
<div class="col-md-6 row_fig">
fig::number_of_faked_dR|Fake per event - dR Matched
</div>
<div class="col-md-6 row_fig">
fig::number_of_matched|Matched per event. The best scenario is obviously a one-to-one correspondence between sim and reco tracks with no ambiguity. It's good to see that almost all of the time (~88%) we unambiguously match either one or both of the zee electrons. (However, it's worth pointing out that there is a contribution to this from unambiguously matched electrons from pileup so the previous statement is not quite correct.)
</div>
<div class="col-md-6 row_fig">
fig::number_of_matched_dR|Matched per event - dR Matched
</div>

</div>

## Fake Rate
We define a "Fake Rate" for gsf-tracking. The denominator of the fake rate consists of superclusters which fulfill the following requirements.

  - Doesn't match within $\Delta R <0.2$ *and* $\Delta p_T / p_{Tsim}<0.1$ of a real sim electron track.
  - HOE<0.15

And the numerator is superclusters that pass the denominator selection *and* produces at least one GSF Track (which is presumably "fake", although truth-matching of these tracks is not used in this metric). Below are the numerator and denominator distributions as well as their ratio.

<div class="row">

<div class="col-md-6 row_fig">
fig::fake_rate_den|Fake Rate Denominator SCs
</div>
<div class="col-md-6 row_fig">
fig::fake_rate_num|Fake Rate Numerator SCs
</div>
<div class="col-md-12 row_fig">
fig::fake_rate|Fake Rate
</div>

</div>



Comparing, for example, the black (`zee-old-default`) and blue (`zee-new-wide`) fake rates there is consistently better performance (ie lower fake rate) using the new working point. The story is similar for tt.

